@@ -5,7 +5,8 @@ except ImportError:
 
 #from ._reader import napari_get_reader
 
-from .napari_dcm_nii import napari_get_reader
+from ._reader import napari_get_reader
+from ._writer import napari_get_writer, napari_write_image
 
 
 
